@@ -1,4 +1,5 @@
-plot.tri<-function(tri.obj,add=F,xlim=range(tri.obj$x),ylim=range(tri.obj$y),...)
+plot.tri<-function(tri.obj,add=F,xlim=range(tri.obj$x),
+                   ylim=range(tri.obj$y),do.points=T,...)
 {
   if(!inherits(tri.obj,"tri"))
     stop("tri.obj must be of class \"tri\"")
@@ -31,6 +32,6 @@ plot.tri<-function(tri.obj,add=F,xlim=range(tri.obj$x),ylim=range(tri.obj$y),...
       for (j in inb)
         lines(c(tri.obj$x[i],tri.obj$x[j]),c(tri.obj$y[i],tri.obj$y[j]), ...)
     }
-  points(tri.obj$x,tri.obj$y)
+  if(do.points) points(tri.obj$x,tri.obj$y)
   if(!add) title("Delaunay triangulation",deparse(substitute(tri.obj)))
 }
