@@ -2,7 +2,7 @@ triangles<-function(tri.obj)
 {
   if(!inherits(tri.obj,"tri"))
     stop("tri.obj must be of class \"tri\"")
-  nt<-summary(tri.obj,print=F)$nt;
+  nt<-summary(tri.obj)$nt;
   ans<-.Fortran("trlist",
                  as.integer(tri.obj$nc),
                  as.integer(tri.obj$lc),
